@@ -110,7 +110,7 @@ class Recognition(Disentangle):
             targets  = self.extract(self.targets, component)
             predicts = self.extract(self.predictions, component)
         else:
-            sys.exit(f"Function filtering {component} not supported yet!")
+            sys.exit(f"Function filtering {component} not yet supported!")
         with warnings.catch_warnings():
             warnings.filterwarnings(action='ignore', message='Mean of empty slice')            
             classwise = average_precision_score(targets, predicts, average=None)
@@ -143,7 +143,7 @@ class Recognition(Disentangle):
             targets  = self.extract(targets, component)
             predicts = self.extract(predicts, component)
         else:
-            sys.exit(f"Function filtering {component} not supported yet!")            
+            sys.exit(f"Function filtering {component} not yet supported!")            
         with warnings.catch_warnings():
             warnings.filterwarnings(action='ignore', message='Mean of empty slice')            
             classwise = average_precision_score(targets, predicts, average=None)
@@ -178,7 +178,7 @@ class Recognition(Disentangle):
                     targets  = self.extract(targets, component)
                     predicts = self.extract(predicts, component)
                 else:
-                    sys.exit(f"Function filtering {component} not supported yet!")                        
+                    sys.exit(f"Function filtering {component} not yet supported!")                        
                 classwise = average_precision_score(targets, predicts, average=None)
                 video_log.append( classwise.reshape([1,-1]) )
         video_log = np.concatenate(video_log, axis=0)         
